#!/bin/bash
set -e
#
# Generate Variables
#

SERVICE="$1"
TIER_CONFIG="$2"

# Abort if no server type is given
if [ "${1:0:1}" = '' ]; then
    echo "Aborting: No druid server type set!"
    exit 1
fi
echo "$(date -Is) startup service $SERVICE"

getConfPath() {
    cluster_conf_base=/opt/druid/conf/druid
    case "$1" in
        _common) echo $cluster_conf_base/_common ;;
        historical) echo $cluster_conf_base/historical ;;
        middleManager) echo $cluster_conf_base/middleManager ;;
        coordinator) echo $cluster_conf_base/coordinator ;;
        overlord) echo $cluster_conf_base/overlord ;;
        broker) echo $cluster_conf_base/broker ;;
        router) echo $cluster_conf_base/router ;;
    esac
}

COMMON_CONF_DIR=$(getConfPath _common)
SERVICE_CONF_DIR=$(getConfPath ${SERVICE})
CONFIG_MAP_BASE=/etc/druid

#
# Copy configmap config(read-only) to target config fold
#
mkdir -p /var/tmp
mkdir -p /var/druid/segments
mkdir -p /var/druid/indexing-logs
mkdir -p /var/druid/task
mkdir -p /var/druid/hadoop-tmp
mkdir -p /var/druid/segment-cache
mkdir -p /var/log/druid/tmp
mkdir -p /data/druid
mkdir -p /data/dump
mkdir -p $COMMON_CONF_DIR
mkdir -p $SERVICE_CONF_DIR

cp $CONFIG_MAP_BASE/_common/* $COMMON_CONF_DIR
cp $CONFIG_MAP_BASE/$1/* $SERVICE_CONF_DIR
# JAVA_OPTS should be set after the configs get copied
JAVA_OPTS="$(cat $SERVICE_CONF_DIR/jvm.config | xargs)"

#
# Update druid server ip with the container ip
#

sed -ri 's/druid.host=.*/druid.host='${POD_IP}'/g' $SERVICE_CONF_DIR/runtime.properties

#
# Run Druid component
#

exec java ${JAVA_OPTS} -cp $COMMON_CONF_DIR:$SERVICE_CONF_DIR:/opt/druid/dist/druid/lib/* org.apache.druid.cli.Main server $SERVICE
